%bcond_without tests

# telemetry and testsdk don't follow azure-cli's versioning scheme.
# They have their own versions in the main repository.
%global         telemetry_version   1.0.6
%global         testsdk_version     0.2.4

%global         srcname     azure-cli
%global         forgeurl    https://github.com/Azure/azure-cli
Version:        2.27.2
%global         tag         %{srcname}-%{version}
%global         distprefix  %{nil}
%forgemeta

Name:           %{srcname}
Release:        1%{?dist}
Summary:        Microsoft Azure Command-Line Tools
License:        MIT
URL:            %forgeurl
Source0:        %forgesource
# All requirements are met, sometimes by newer versions, except for two:
# humanfriendly: https://src.fedoraproject.org/rpms/python-humanfriendly/pull-request/1
# portalocker:   https://src.fedoraproject.org/rpms/python-portalocker/pull-request/2
Patch0:         azure-cli-requirements-fix.patch

BuildArch:      noarch

BuildRequires:  python3-devel
BuildRequires:  python3-pip
BuildRequires:  python3-setuptools
BuildRequires:  python3-wheel
BuildRequires:  pyproject-rpm-macros

%if %{with tests}
BuildRequires:  python3dist(azure-devtools)
BuildRequires:  python3dist(azure-mgmt-managedservices)
BuildRequires:  python3dist(javaproperties)
BuildRequires:  python3dist(jsondiff)
BuildRequires:  python3dist(pkginfo)
BuildRequires:  python3dist(pytest)
BuildRequires:  python3dist(vcrpy)
%endif

%description
Microsoft Azure Command-Line Tools

# python-azure-cli-core
%package -n python3-%{srcname}-core
Summary:        Microsoft Azure Command-Line Tools Core Module
Requires:       %{name} = %{version}-%{release}

%description -n python3-%{srcname}-core
Microsoft Azure Command-Line Tools Core Module

# python-azure-cli-telemetry
%package -n python3-%{srcname}-telemetry
Summary:        Microsoft Azure CLI Telemetry Package
Requires:       %{name} = %{version}-%{release}

%description -n python3-%{srcname}-telemetry
Microsoft Azure CLI Telemetry Package

# python-azure-cli-testsdk
%package -n python3-%{srcname}-testsdk
Summary:        Microsoft Azure CLI SDK testing tools
Requires:       %{name} = %{version}-%{release}

%description -n python3-%{srcname}-testsdk
Microsoft Azure CLI SDK testing tools


%prep
%forgesetup
%patch0 -p1


%generate_buildrequires
%pyproject_buildrequires -N src/azure-cli/requirements.py3.Linux.txt


%build
PROJECTS=("azure-cli azure-cli-core azure-cli-telemetry azure-cli-testsdk")
for PROJECT in ${PROJECTS[@]}; do
    pushd src/${PROJECT}
        %pyproject_wheel
    popd
done


%install
%pyproject_install

# Batch scripts are only for Windows.
rm -f %{buildroot}%{_bindir}/az.bat

# Install the az bash completion script properly.
install -D -p -m 0644 %{buildroot}%{_bindir}/az.completion.sh \
    %{buildroot}%{_sysconfdir}/bash-completion.d/azure-cli
rm -f %{buildroot}%{_bindir}/az.completion.sh


%if %{with tests}
%check
# NOTE(mhayden): The azure-cli tests include preview/beta tests that aren't even
# passing in the released version of azure-cli installed via pip. There are
# hundreds of failures. Skipping the azure-cli tests until this can be resolved.

# Test azure-cli-core.
%pytest --disable-warnings \
    -k "not test_metadata_url_endpoint and not test_get_msal_token and not test_help_loads" \
    src/azure-cli-core

# Test azure-cli-telemetry.
%pytest --disable-warnings src/azure-cli-telemetry

# azure-cli-testsdk has no tests.
%endif


%files
%doc README.md
%license LICENSE
# Executable-related files/directories.
%{_bindir}/az
%dir %{_sysconfdir}/bash-completion.d/
%{_sysconfdir}/bash-completion.d/%{srcname}
# Python sitelib files and directories.
%dir %{python3_sitelib}/azure
%{python3_sitelib}/azure/cli
%{python3_sitelib}/azure_cli-%{version}.dist-info/
# Prevent azure-cli from grabbing all of the files underneath azure/cli.
%exclude %{python3_sitelib}/azure/cli/core
%exclude %{python3_sitelib}/azure/cli/telemetry
%exclude %{python3_sitelib}/azure/cli/testsdk


%files -n python3-%{srcname}-core
%doc README.md
%license LICENSE
%{python3_sitelib}/azure/cli/core
%{python3_sitelib}/azure_cli_core-%{version}.dist-info/


%files -n python3-%{srcname}-telemetry
%doc README.md
%license LICENSE
%{python3_sitelib}/azure/cli/telemetry
%{python3_sitelib}/azure_cli_telemetry-%{telemetry_version}.dist-info/


%files -n python3-%{srcname}-testsdk
%doc README.md
%license LICENSE
%{python3_sitelib}/azure/cli/testsdk
%{python3_sitelib}/azure_cli_testsdk-%{testsdk_version}.dist-info/


%changelog
* Mon Aug 23 2021 Major Hayden <major@mhtx.net> - 2.27.2-1
- new version

* Wed Aug 11 2021 Major Hayden <major@mhtx.net> - 2.27.1-1
- Update to 2.27.1

* Mon Aug 09 2021 Major Hayden <major@mhtx.net> - 2.27.0-1
- Update to 2.27.0

* Tue Jun 01 2021 Major Hayden <major@mhtx.net> - 2.26.1-1
- First package.
